<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Manager Utenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Amministrazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Aggiungi un nuovo utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Aggiungi un account utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Re-inserisci la password del nuovo utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>conferma password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nome utente del nuovo utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Nome di Login dell&apos;utente:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Inserisci il nome utente del nuovo utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>nome utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Password per il nuovo utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Password dell&apos;utente:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Inserisci la password per il nuovo utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Conferma la password dell&apos;utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Elimina un account utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Seleziona utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Seleziona l&apos;utente da eliminare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Utente da eliminare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Elimina anche la cartella home dell&apos;utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Elimina la cartella home dell&apos;utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Rinomina Account Utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Seleziona utente da modificare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Nuovo nome utente:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Cambia la Password Utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>nuova password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Conferma la nuova password:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>conferma la nuova password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nuova password utente:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Ripara una configurazione utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Modifica Account Utente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Seleziona un utente da riparare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Utente da modificare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Ripristina impostaz. predefinite</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Riporta le configurazioni del browser a quelle predefinite di MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configurazioni di Mozilla (Iceweasel o Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Ripristina i gruppi di appartenenza a quelli predefiniti di MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Gruppi di appartenenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Cambia Impostazioni dell&apos;Autologin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Log-in automatico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Richiesta della password al login</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Copia/Sincronizza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Copia tra  Desktops</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Seleziona il desktop da cui copiare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Seleziona per copiare solo i file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Copia solo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Seleziona il desktop su cui copiare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Copia su:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Copia da:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Seleziona per copiare e poi eliminare le differenze</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Sincronizza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Seleziona per copiare/sincronizzare la cartella Condivisa </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Cartella Condivisa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Seleziona per copiare/sincronizzare l&apos;intera home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Intera home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Seleziona per copiare/sincronizzare la configurazione del browser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configurazione di Mozilla (Firefox o Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Seleziona per copiare/sincronizzare la cartella Documenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Cartella Documenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Cosa copiare/sincronizzare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Avanzamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Stato dei cambiamenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Stato:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Avanzamento dei cambiamenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Aggiungi/Rimuovi gruppi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Aggiungi un gruppo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nome del gruppo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>nome del gruppo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Elimina gruppo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Gruppo da eliminare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Gruppi di appartenenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Appartenenza utente ai gruppi (cambiare i gruppi selezionando/deselezionando le caselle corrispondenti):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>* Si prega di ricontrollare le tue selezioni prima di applicare, assegnando l&apos;appartenenza a gruppi sbagliati si può danneggiare il sistema. Se hai fatto un errore, utilizza la scheda Ripara per ripristinare le appartenenze originali.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Applica tutti i cambiamenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancella tutte le modifiche quando chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="173"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="617"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="819"/>
        <location filename="../mainwindow.cpp" line="932"/>
        <source>none</source>
        <translation>nessuno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>La configurazione utente verrà riparata. Ora chiudi tutte le altre applicazioni. Quando avrai finito dovrai riavviare o chiudere il computer. Sei sicuro di voler fare la riparazione ora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation>Le impostazioni di Mozilla sono state ripristinate.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin options</source>
        <translation>Opzioni Autologin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>L&apos;Autologin è stato disabilitato per l&apos;account &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>L&apos;Autologin è stato abilitato per l&apos;account &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Devi specificare una destinazione dove compiere l&apos;operazione di &quot;copia su&quot;. Non puoi copiare nel desktop in cui hai eseguito l&apos;accesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Prima della copia, chiudi tutte le altre applicazioni. Assicurati che la destinazione della copia abbia abbastanza spazio libero da contenere i file che stai copiando. La copiatura tra  desktops potrebbe sovrascrivere o eliminare i tuoi file o preferenze sul desktop di destinazione. Sei sicuro di voler procedere?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronizzazione del desktop in corso...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Copying desktop...</source>
        <translation>Copia del desktop in corso...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Il nome utente deve essere lungo almeno 2 caratteri. Per favore, seleziona un nome più lungo prima di procedere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Il nome utente deve essere scritto in minuscolo e
non può contenere caratteri speciali o spazi
prego, scegli un altro nome prima di procedere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Spiacente, quel nome è già in uso. Prego, inserisci un nome differente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>La Password inserita non corrisponde. Prego riprova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>La password deve essere lunga almeno 2 caratteri. Per favore, scegli un nome più lungo prima di procedere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>The user was added ok.</source>
        <translation>Utente aggiunto con successo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="357"/>
        <source>Failed to add the user.</source>
        <translation>Aggiunta dell&apos;utente fallita.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Password successfully changed.</source>
        <translation>Password modificata con successo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Failed to change password.</source>
        <translation>Cambio della password fallita.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Questa azione non può essere annullata. Sei sicuro di voler eliminare l&apos;utente %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>The user has been deleted.</source>
        <translation>L&apos;utente è stato eliminato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Failed to delete the user.</source>
        <translation>Eliminazione dell&apos;utente fallita.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Il nome del gruppo deve essere lungo almeno 2 caratteri. Prego, seleziona un nome più lungo prima di procedere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>ll nome del gruppo deve essere scritto in minuscolo e
non può contenere caratteri speciali o spazi
prego, scegli un altro nome prima di procedere.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Spiacente, esiste già un gruppo con quel nome. Prego, inserisci un nome differente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>The system group was added ok.</source>
        <translation>Il gruppo di sistema è stato aggiunto con successo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Failed to add the system group.</source>
        <translation>Aggiunta del gruppo di sistema fallita.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Questa azione non può essere annullata. Sei sicuro di volere eliminare il gruppo %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>The group has been deleted.</source>
        <translation>Il gruppo è stato eliminato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Failed to delete the group.</source>
        <translation>Eliminazione del gruppo fallita.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>The changes have been applied.</source>
        <translation>I cambiamenti sono stati applicati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Failed to apply group changes</source>
        <translation>Applicazione dei cambiamenti del gruppo fallita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The selected user name is currently in use.</source>
        <translation>Il nome utente selezionato è attualmente in uso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Per rinominare questo utente, uscire e fare il log-in utilizzando un altro account utente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Spiacente, questo nome è già in uso nel tuo sistema. Prego, inserisci un nome differente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Non si è riusciti a rinominare l&apos;utente. Prego, assicurati che quell&apos;utente non abbia già effettuato l&apos;accesso, potrebbe essere necessario riavviare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="543"/>
        <source>The user was renamed.</source>
        <translation>L&apos;utente è stato rinominato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronizzazione del desktop in corso... OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Copying desktop...ok</source>
        <translation>Copia del desktop in corso... OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronizzazione del desktop... fallita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Copying desktop...failed</source>
        <translation>Copia del desktop... fallita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <location filename="../mainwindow.cpp" line="871"/>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>browse...</source>
        <translation>navigazione...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Gestore di configurazione degli utenti di facile uso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="787"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="802"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="872"/>
        <source>Select folder to copy to</source>
        <translation>Seleziona cartella su cui copiare</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Devi eseguire questo programma come amministratore</translation>
    </message>
</context>
</TS>
